@@ -22,10 +22,13 @@
 #   are deemed to be part of the source code.
 #
 
+import time
+from datetime import datetime
+import threading
+import optparse
+import libxml2
 from rteval.Log import Log
 from rteval.rtevalConfig import rtevalCfgSection
-from datetime import datetime
-import time, libxml2, threading, optparse
 
 __all__ = ["rtevalRuntimeError", "rtevalModulePrototype", "ModuleContainer", "RtEvalModules"]
 
@@ -38,7 +41,7 @@ class rtevalRuntimeError(RuntimeError):
 
 
 class rtevalModulePrototype(threading.Thread):
-    "Prototype class for rteval modules - must be inherited by the real module"
+    """ Prototype rteval modules class - to be inherited by the real module """
 
     def __init__(self, modtype, name, logger=None):
         if logger and not isinstance(logger, Log):
@@ -60,63 +63,64 @@ class rtevalModulePrototype(threading.Thread):
 
 
     def _log(self, logtype, msg):
-        "Common log function for rteval modules"
+        """ Common log function for rteval modules """
         if self.__logger:
             self.__logger.log(logtype, "[%s] %s" % (self._name, msg))
 
 
     def isReady(self):
-        "Returns a boolean if the module is ready to run"
+        """ Returns a boolean if the module is ready to run """
         if self._donotrun:
             return True
         return self.__ready
 
 
     def _setReady(self, state=True):
-        "Sets the ready flag for the module"
+        """ Sets the ready flag for the module """
         self.__ready = state
 
 
     def hadRuntimeError(self):
-        "Returns a boolean if the module had a RuntimeError"
+        """ Returns a boolean if the module had a RuntimeError """
         return self.__runtimeError
 
 
     def _setRuntimeError(self, state=True):
-        "Sets the runtimeError flag for the module"
+        """ Sets the runtimeError flag for the module """
         self.__runtimeError = state
 
 
     def setStart(self):
-        "Sets the start event state"
+        """ Sets the start event state """
         self.__events["start"].set()
         self.__timestamps["start_set"] = datetime.now()
 
 
     def shouldStart(self):
-        "Returns the start event state - indicating the module can start"
+        """Returns the start event state - indicating the module can start """
         return self.__events["start"].isSet()
 
 
     def setStop(self):
-        "Sets the stop event state"
+        """ Sets the stop event state """
         self.__events["stop"].set()
         self.__timestamps["stop_set"] = datetime.now()
 
 
     def shouldStop(self):
-        "Returns the stop event state - indicating the module should stop"
+        """ Returns the stop event state - indicating the module should stop """
         return self.__events["stop"].isSet()
 
 
     def _setFinished(self):
-        "Sets the finished event state - indicating the module has completed"
+        """ Sets the finished event state - indicating the module has completed
+        """
         self.__events["finished"].set()
         self.__timestamps["finished_set"] = datetime.now()
 
 
-    def WaitForCompletion(self, wtime = None):
-        "Blocks until the module has completed its workload"
+    def WaitForCompletion(self, wtime=None):
+        """ Blocks until the module has completed its workload """
         if not self.shouldStart():
             # If it hasn't been started yet, nothing to wait for
             return None
@@ -124,32 +128,42 @@ class rtevalModulePrototype(threading.Thread):
 
 
     def _WorkloadSetup(self):
-        "Required module method, which purpose is to do the initial workload setup, preparing for _WorkloadBuild()"
+        """ Required module method, which purpose is to do the initial workload
+        setup, preparing for _WorkloadBuild()
+        """
         raise NotImplementedError("_WorkloadSetup() method must be implemented in the %s module" % self._name)
 
 
     def _WorkloadBuild(self):
-        "Required module method, which purpose is to compile additional code needed for the worklaod"
+        """ Required module method, which purpose is to compile additional code
+        needed for the worklaod
+        """
         raise NotImplementedError("_WorkloadBuild() method must be implemented in the %s module" % self._name)
 
 
     def _WorkloadPrepare(self):
-        "Required module method, which will initialise and prepare the workload just before it is about to start"
+        """ Required module method, which will initialise and prepare the
+        workload just before it is about to start
+        """
         raise NotImplementedError("_WorkloadPrepare() method must be implemented in the %s module" % self._name)
 
 
     def _WorkloadTask(self):
-        "Required module method, which kicks off the workload"
+        """ Required module method, which kicks off the workload """
         raise NotImplementedError("_WorkloadTask() method must be implemented in the %s module" % self._name)
 
 
     def WorkloadAlive(self):
-        "Required module method, which should return True if the workload is still alive"
+        """ Required module method, which should return True if the workload is
+        still alive
+        """
         raise NotImplementedError("WorkloadAlive() method must be implemented in the %s module" % self._name)
 
 
     def _WorkloadCleanup(self):
-        "Required module method, which will be run after the _WorkloadTask() has completed or been aborted by the 'stop event flag'"
+        """ Required module method, which will be run after the _WorkloadTask()
+        has completed or been aborted by the 'stop event flag'
+        """
         raise NotImplementedError("_WorkloadCleanup() method must be implemented in the %s module" % self._name)
 
 
@@ -189,9 +203,6 @@ class rtevalModulePrototype(threading.Thread):
 
                 if self.shouldStop():
                     break
-                if not self.WorkloadAlive():
-                    self._log(Log.DEBUG, "%s workload stopped running." % self._module_type)
-                    break
                 time.sleep(self.__sleeptime)
 
             self.__timestamps["runloop_stop"] = datetime.now()
@@ -203,7 +214,9 @@ class rtevalModulePrototype(threading.Thread):
 
 
     def MakeReport(self):
-        "required module method, needs to return an libxml2.xmlNode object with the the results from running"
+        """ required module method, needs to return an libxml2.xmlNode object
+        with the the results from running
+        """
         raise NotImplementedError("MakeReport() method must be implemented in the%s module" % self._name)
 
 
@@ -218,7 +231,7 @@ class rtevalModulePrototype(threading.Thread):
 
 
 
-class ModuleContainer(object):
+class ModuleContainer:
     """The ModuleContainer keeps an overview over loaded modules and the objects it
 will instantiate.  These objects are accessed by iterating the ModuleContainer object."""
 
@@ -259,7 +272,7 @@ reference from the first import"""
             return mod
 
 
-    def ModuleInfo(self, modname, modroot = None):
+    def ModuleInfo(self, modname, modroot=None):
         """Imports a module and calls the modules' ModuleInfo() function and returns
 the information provided by the module"""
 
@@ -291,7 +304,7 @@ the information provided by the module"""
 
             grparser = optparse.OptionGroup(parser, "Options for the %s module" % shortmod)
             for (o, s) in list(opts.items()):
-                descr   = 'descr' in s and s['descr'] or ""
+                descr = 'descr' in s and s['descr'] or ""
                 metavar = 'metavar' in s and s['metavar'] or None
 
                 try:
@@ -314,7 +327,7 @@ the information provided by the module"""
             parser.add_option_group(grparser)
 
 
-    def InstantiateModule(self, modname, modcfg, modroot = None):
+    def InstantiateModule(self, modname, modcfg, modroot=None):
         """Imports a module and instantiates an object from the modules create() function.
 The instantiated object is returned in this call"""
 
@@ -331,7 +344,7 @@ returned when a ModuleContainer object is iterated over"""
         self.__modobjects[modname] = modobj
 
 
-    def ExportModule(self, modname, modroot = None):
+    def ExportModule(self, modname, modroot=None):
         "Export module info, used to transfer an imported module to another ModuleContainer"
         if modroot is None:
             modroot = self.__modules_root
@@ -369,28 +382,31 @@ returned when a ModuleContainer object is iterated over"""
 
 
     def __next__(self):
-        """Internal Python iterating method, returns the next
-module name and object to be processed"""
+        """ Internal Python iterating method, returns the next
+        module name and object to be processed
+        """
 
         if len(self.__iter_list) == 0:
             self.__iter_list = None
             raise StopIteration
-        else:
-            modname = self.__iter_list.pop()
-            return (modname, self.__modobjects[modname])
+        modname = self.__iter_list.pop()
+        return (modname, self.__modobjects[modname])
 
 
 
-class RtEvalModules(object):
-    """RtEvalModules should normally be inherrited by a more specific module class.
-    This class takes care of managing imported modules and have methods for starting
-    and stopping the workload these modules contains."""
+class RtEvalModules:
+    """ RtEvalModules should normally be inherrited by a more specific module
+    class.  This class takes care of managing imported modules and has methods
+    for starting and stopping the workload these modules contains.
+    """
 
     def __init__(self, config, modules_root, logger):
-        """Initialises the RtEvalModules() internal variables.  The modules_root
-argument should point at the root directory where the modules will be loaded from.
-The logger argument should point to a Log() object which will be used for logging
-and will also be given to the instantiated objects during module import."""
+        """ Initialises the RtEvalModules() internal variables.
+        The modules_root argument should point at the root directory where
+        the modules will be loaded from. The logger argument should point
+        to a Log() object which will be used for logging and will also be given
+        to the instantiated objects during module import.
+        """
 
         self._cfg = config
         self._logger = logger
@@ -405,7 +421,7 @@ and will also be given to the instantiated objects during module import."""
         "Imports a module exported by ModuleContainer::ExportModule()"
         return self.__modules.ImportModule(module)
 
-    def _InstantiateModule(self, modname, modcfg, modroot = None):
+    def _InstantiateModule(self, modname, modcfg, modroot=None):
         "Imports a module and returns an instantiated object from the module"
         return self.__modules.InstantiateModule(modname, modcfg, modroot)
 
@@ -436,9 +452,9 @@ and will also be given to the instantiated objects during module import."""
 
 
     def Start(self):
-        """Prepares all the imported modules workload to start, but they will not
-start their workloads yet"""
-
+        """ Prepares all the imported modules workload to start, but they
+        will not start their workloads yet
+        """
         if self.__modules.ModulesLoaded() == 0:
             raise rtevalRuntimeError("No %s modules configured" % self._module_type)
 
@@ -516,7 +532,7 @@ start their workloads yet"""
         self.__timestamps['stop'] = datetime.now()
 
 
-    def WaitForCompletion(self, wtime = None):
+    def WaitForCompletion(self, wtime=None):
         """Waits for the running modules to complete their running"""
 
         self._logger.log(Log.INFO, "Waiting for %s modules to complete" % self._module_type)
