@@ -24,17 +24,20 @@
 #   are deemed to be part of the source code.
 #
 
-import sys, os, os.path, glob, subprocess
-from signal import SIGTERM
+import sys
+import os
+import os.path
+import glob
+import subprocess
 from rteval.modules import rtevalRuntimeError
 from rteval.modules.loads import CommandLineLoad
 from rteval.Log import Log
-from rteval.misc import expand_cpulist,compress_cpulist
+from rteval.misc import expand_cpulist, compress_cpulist
 from rteval.systopology import SysTopology
 
-kernel_prefix="linux-5.1"
+kernel_prefix = "linux-5.7"
 
-class KBuildJob(object):
+class KBuildJob:
     '''Class to manage a build job bound to a particular node'''
 
     def __init__(self, node, kdir, logger=None, cpulist=None):
@@ -55,9 +58,12 @@ class KBuildJob(object):
         else:
             self.jobs = self.calc_jobs_per_cpu() * len(self.node)
         self.log(Log.DEBUG, "node %d: jobs == %d" % (int(node), self.jobs))
-        self.runcmd = "%s make O=%s -C %s -j%d bzImage modules" % (self.binder, self.objdir, self.kdir, self.jobs)
-        self.cleancmd = "%s make O=%s -C %s clean allmodconfig" % (self.binder, self.objdir, self.kdir)
-        self.log(Log.DEBUG, "node%d kcompile command: %s" % (int(node), self.runcmd))
+        self.runcmd = "%s make O=%s -C %s -j%d bzImage modules" \
+                % (self.binder, self.objdir, self.kdir, self.jobs)
+        self.cleancmd = "%s make O=%s -C %s clean allmodconfig" \
+                % (self.binder, self.objdir, self.kdir)
+        self.log(Log.DEBUG, "node%d kcompile command: %s" \
+                % (int(node), self.runcmd))
 
     def __str__(self):
         return self.runcmd
@@ -93,9 +99,9 @@ class KBuildJob(object):
                                       stdin=sin, stdout=sout, stderr=serr)
 
     def isrunning(self):
-        if self.jobid == None:
+        if self.jobid is None:
             return False
-        return (self.jobid.poll() == None)
+        return self.jobid.poll() is None
 
     def stop(self):
         if not self.jobid:
@@ -113,7 +119,7 @@ class Kcompile(CommandLineLoad):
         self.logger = logger
 
     def _extract_tarball(self):
-        if self.source == None:
+        if self.source is None:
             raise rtevalRuntimeError(self, " no source tarball specified!")
         self._log(Log.DEBUG, "unpacking kernel tarball")
         tarargs = ['tar', '-C', self.builddir, '-x']
@@ -134,10 +140,12 @@ class Kcompile(CommandLineLoad):
             return
         self._log(Log.DEBUG, "removing kcompile directories in %s" % self.builddir)
         null = os.open("/dev/null", os.O_RDWR)
-        cmd=["rm",  "-rf", os.path.join(self.builddir, "kernel*"), os.path.join(self.builddir, "node*")]
-        ret = subprocess.call(cmd,stdin=null, stdout=null, stderr=null)
+        cmd = ["rm", "-rf", os.path.join(self.builddir, "kernel*"),
+               os.path.join(self.builddir, "node*")]
+        ret = subprocess.call(cmd, stdin=null, stdout=null, stderr=null)
         if ret:
-            raise rtevalRuntimeError(self, "error removing builddir (%s) (ret=%d)" % (self.builddir, ret))
+            raise rtevalRuntimeError(self, \
+                "error removing builddir (%s) (ret=%d)" % (self.builddir, ret))
 
     def _WorkloadSetup(self):
         # find our source tarball
@@ -148,27 +156,27 @@ class Kcompile(CommandLineLoad):
             self.source = tarfile
         else:
             tarfiles = glob.glob(os.path.join(self.srcdir, "%s*" % kernel_prefix))
-            if len(tarfiles):
+            if tarfiles:
                 self.source = tarfiles[0]
             else:
                 raise rtevalRuntimeError(self, " no kernel tarballs found in %s" % self.srcdir)
 
         # check for existing directory
-        kdir=None
-        names=os.listdir(self.builddir)
+        kdir = None
+        names = os.listdir(self.builddir)
         for d in names:
             if d.startswith(kernel_prefix):
-                kdir=d
+                kdir = d
                 break
-        if kdir == None:
+        if kdir is None:
             self._extract_tarball()
             names = os.listdir(self.builddir)
             for d in names:
                 self._log(Log.DEBUG, "checking %s" % d)
                 if d.startswith(kernel_prefix):
-                    kdir=d
+                    kdir = d
                     break
-        if kdir == None:
+        if kdir is None:
             raise rtevalRuntimeError(self, "Can't find kernel directory!")
         self.mydir = os.path.join(self.builddir, kdir)
         self._log(Log.DEBUG, "mydir = %s" % self.mydir)
@@ -180,22 +188,23 @@ class Kcompile(CommandLineLoad):
         self.cpus = {}
         self.nodes = self.topology.getnodes()
         for n in self.nodes:
-            self.cpus[n] = [ int(c.split('/')[-1][3:]) for c in glob.glob('/sys/devices/system/node/node%s/cpu[0-9]*' % n) ]
+            self.cpus[n] = [int(c.split('/')[-1][3:]) for c in glob.glob('/sys/devices/system/node/node%s/cpu[0-9]*' % n)]
             self.cpus[n].sort()
 
             # if a cpulist was specified, only allow cpus in that list on the node
             if self.cpulist:
-                self.cpus[n] = [ c for c in self.cpus[n] if str(c) in expand_cpulist(self.cpulist) ]
+                self.cpus[n] = [c for c in self.cpus[n] if str(c) in expand_cpulist(self.cpulist)]
 
         # remove nodes with no cpus available for running
-        for node,cpus in self.cpus.items():
+        for node, cpus in self.cpus.items():
             if not cpus:
                 self.nodes.remove(node)
                 self._log(Log.DEBUG, "node %s has no available cpus, removing" % node)
 
         for n in self.nodes:
             self._log(Log.DEBUG, "Configuring build job for node %d" % int(n))
-            self.buildjobs[n] = KBuildJob(self.topology[n], self.mydir, self.logger, self.cpus[n] if self.cpulist else None)
+            self.buildjobs[n] = KBuildJob(self.topology[n], self.mydir, \
+                self.logger, self.cpus[n] if self.cpulist else None)
             self.args.append(str(self.buildjobs[n])+";")
 
 
@@ -229,7 +238,7 @@ class Kcompile(CommandLineLoad):
             os.close(err)
         # clean up object dirs and make sure each has a config file
         for n in self.nodes:
-            self.buildjobs[n].clean(sin=null,sout=null,serr=null)
+            self.buildjobs[n].clean(sin=null, sout=null, serr=null)
         os.close(null)
         self._setReady()
 
@@ -256,8 +265,8 @@ class Kcompile(CommandLineLoad):
                 # -2 is returned when user forced stop of execution (CTRL-C).
                 if self.buildjobs[n].jobid is not None:
                     if self.buildjobs[n].jobid.returncode != 0 and self.buildjobs[n].jobid.returncode != -2:
-                        raise RuntimeError("kcompile module failed to run (returned %d), please check logs for more detail"
-                                % self.buildjobs[n].jobid.returncode)
+                        raise RuntimeError("kcompile module failed to run (returned %d), please check logs for more detail" \
+                            % self.buildjobs[n].jobid.returncode)
                 self._log(Log.INFO, "Starting load on node %d" % n)
                 self.buildjobs[n].run(self.__nullfd, self.__outfd, self.__errfd)
 
@@ -267,8 +276,7 @@ class Kcompile(CommandLineLoad):
             if self.buildjobs[n].jobid.poll() is not None:
                 # Check return code (see above).
                 if self.buildjobs[n].jobid.returncode != 0 and self.buildjobs[n].jobid.returncode != -2:
-                    raise RuntimeError("kcompile module failed to run (returned %d), please check logs for more detail"
-                            % self.buildjobs[n].jobid.returncode)
+                    raise RuntimeError("kcompile module failed to run (returned %d), please check logs for more detail" % self.buildjobs[n].jobid.returncode)
                 return False
 
         return True
@@ -277,7 +285,7 @@ class Kcompile(CommandLineLoad):
     def _WorkloadCleanup(self):
         self._log(Log.DEBUG, "out of stopevent loop")
         for n in self.buildjobs:
-            if self.buildjobs[n].jobid.poll() == None:
+            if self.buildjobs[n].jobid.poll() is None:
                 self._log(Log.DEBUG, "stopping job on node %d" % int(n))
                 self.buildjobs[n].jobid.terminate()
                 self.buildjobs[n].jobid.wait()
@@ -294,7 +302,7 @@ class Kcompile(CommandLineLoad):
 
 def ModuleParameters():
     return {"source":   {"descr": "Source tar ball",
-                         "default": "linux-5.1.tar.xz",
+                         "default": "linux-5.7.tar.xz",
                          "metavar": "TARBALL"},
             "jobspercore": {"descr": "Number of working threads per core",
                             "default": 2,
