@@ -25,12 +25,18 @@
 #   are deemed to be part of the source code.
 #
 
-import os, sys, subprocess, signal, libxml2, shutil, tempfile, time
+import os
+import subprocess
+import signal
+import time
+import tempfile
+import math
+import libxml2
 from rteval.Log import Log
 from rteval.modules import rtevalModulePrototype
 from rteval.misc import expand_cpulist, online_cpus, cpuinfo
 
-class RunData(object):
+class RunData:
     '''class to keep instance data from a cyclictest run'''
     def __init__(self, coreid, datatype, priority, logfnc):
         self.__id = coreid
@@ -51,7 +57,7 @@ class RunData(object):
         self._log = logfnc
 
     def __str__(self):
-        retval =  "id:         %s\n" % self.__id
+        retval = "id:         %s\n" % self.__id
         retval += "type:       %s\n" % self.__type
         retval += "numsamples: %d\n" % self.__numsamples
         retval += "min:        %d\n" % self.__min
@@ -63,18 +69,21 @@ class RunData(object):
 
     def sample(self, value):
         self.__samples[value] += self.__samples.setdefault(value, 0) + 1
-        if value > self.__max: self.__max = value
-        if value < self.__min: self.__min = value
+        if value > self.__max:
+            self.__max = value
+        if value < self.__min:
+            self.__min = value
         self.__numsamples += 1
 
     def bucket(self, index, value):
         self.__samples[index] = self.__samples.setdefault(index, 0) + value
-        if value and index > self.__max: self.__max = index
-        if value and index < self.__min: self.__min = index
+        if value and index > self.__max:
+            self.__max = index
+        if value and index < self.__min:
+            self.__min = index
         self.__numsamples += value
 
     def reduce(self):
-        import math
 
         # check to see if we have any samples and if we
         # only have 1 (or none) set the calculated values
@@ -87,9 +96,8 @@ class RunData(object):
 
         self._log(Log.INFO, "reducing %s" % self.__id)
         total = 0
-        keys = self.__samples.keys()
+        keys = list(self.__samples.keys())
         keys.sort()
-        sorted = []
 
         mid = self.__numsamples / 2
 
@@ -167,7 +175,7 @@ class RunData(object):
 
             hist_n = rep_n.newChild(None, 'histogram', None)
             hist_n.newProp('nbuckets', str(len(self.__samples)))
-            keys = self.__samples.keys()
+            keys = list(self.__samples.keys())
             keys.sort()
             for k in keys:
                 if self.__samples[k] == 0:
@@ -207,12 +215,13 @@ class Cyclictest(rtevalModulePrototype):
 
         # create a RunData object for each core we'll measure
         for core in self.__cpus:
-            self.__cyclicdata[core] = RunData(core, 'core',self.__priority,
+            self.__cyclicdata[core] = RunData(core, 'core', self.__priority,
                                               logfnc=self._log)
             self.__cyclicdata[core].description = info[core]['model name']
 
         # Create a RunData object for the overall system
-        self.__cyclicdata['system'] = RunData('system', 'system', self.__priority,
+        self.__cyclicdata['system'] = RunData('system',
+                                              'system', self.__priority,
                                               logfnc=self._log)
         self.__cyclicdata['system'].description = ("(%d cores) " % self.__numcores) + info['0']['model name']
 
@@ -225,15 +234,8 @@ class Cyclictest(rtevalModulePrototype):
         self.__breaktraceval = None
 
 
-    def __getmode(self):
-        if self.__numanodes > 1:
-            self._log(Log.DEBUG, "running in NUMA mode (%d nodes)" % self.__numanodes)
-            return '--numa'
-        self._log(Log.DEBUG, "running in SMP mode")
-        return '--smp'
-
-
-    def __get_debugfs_mount(self):
+    @staticmethod
+    def __get_debugfs_mount():
         ret = None
         mounts = open('/proc/mounts')
         for l in mounts:
@@ -247,7 +249,6 @@ class Cyclictest(rtevalModulePrototype):
 
     def _WorkloadSetup(self):
         self.__cyclicprocess = None
-        pass
 
 
     def _WorkloadBuild(self):
@@ -255,11 +256,11 @@ class Cyclictest(rtevalModulePrototype):
 
 
     def _WorkloadPrepare(self):
-        self.__interval = self.__cfg.has_key('interval') and '-i%d' % int(self.__cfg.interval) or ""
+        self.__interval = 'interval' in self.__cfg and '-i%d' % int(self.__cfg.interval) or ""
 
         self.__cmd = ['cyclictest',
                       self.__interval,
-                      '-qmun',
+                      '-qmu',
                       '-h %d' % self.__buckets,
                       "-p%d" % int(self.__priority),
                       ]
@@ -267,18 +268,19 @@ class Cyclictest(rtevalModulePrototype):
             self.__cmd.append('-t%d' % self.__numcores)
             self.__cmd.append('-a%s' % self.__cpulist)
         else:
-            self.__cmd.append(self.__getmode())
+            self.__cmd.append('-t')
+            self.__cmd.append('-a')
 
-        if self.__cfg.has_key('threads') and self.__cfg.threads:
+        if 'threads' in self.__cfg and self.__cfg.threads:
             self.__cmd.append("-t%d" % int(self.__cfg.threads))
 
-        if self.__cfg.has_key('breaktrace') and self.__cfg.breaktrace:
+        if 'breaktrace' in self.__cfg and self.__cfg.breaktrace:
             self.__cmd.append("-b%d" % int(self.__cfg.breaktrace))
             self.__cmd.append("--tracemark")
             self.__cmd.append("--notrace")
 
         # Buffer for cyclictest data written to stdout
-        self.__cyclicoutput = tempfile.SpooledTemporaryFile(mode='rw+b')
+        self.__cyclicoutput = tempfile.SpooledTemporaryFile(mode='w+b')
 
 
     def _WorkloadTask(self):
@@ -290,7 +292,7 @@ class Cyclictest(rtevalModulePrototype):
         self.__nullfp = os.open('/dev/null', os.O_RDWR)
 
         debugdir = self.__get_debugfs_mount()
-        if self.__cfg.has_key('breaktrace') and self.__cfg.breaktrace and debugdir:
+        if 'breaktrace' in self.__cfg and self.__cfg.breaktrace and debugdir:
             # Ensure that the trace log is clean
             trace = os.path.join(debugdir, 'tracing', 'trace')
             fp = open(os.path.join(trace), "w")
@@ -299,22 +301,26 @@ class Cyclictest(rtevalModulePrototype):
             fp.close()
 
         self.__cyclicoutput.seek(0)
-        self.__cyclicprocess = subprocess.Popen(self.__cmd,
-                                                stdout=self.__cyclicoutput,
-                                                stderr=self.__nullfp,
-                                                stdin=self.__nullfp)
-        self.__started = True
+        try:
+            self.__cyclicprocess = subprocess.Popen(self.__cmd,
+                                                    stdout=self.__cyclicoutput,
+                                                    stderr=self.__nullfp,
+                                                    stdin=self.__nullfp)
+            self.__started = True
+        except OSError:
+            self.__started = False
 
 
     def WorkloadAlive(self):
         if self.__started:
             return self.__cyclicprocess.poll() is None
-        else:
-            return False
+        return False
 
 
     def _WorkloadCleanup(self):
-        while self.__cyclicprocess.poll() == None:
+        if not self.__started:
+            return
+        while self.__cyclicprocess.poll() is None:
             self._log(Log.DEBUG, "Sending SIGINT")
             os.kill(self.__cyclicprocess.pid, signal.SIGINT)
             time.sleep(2)
@@ -322,6 +328,7 @@ class Cyclictest(rtevalModulePrototype):
         # now parse the histogram output
         self.__cyclicoutput.seek(0)
         for line in self.__cyclicoutput:
+            line = bytes.decode(line)
             if line.startswith('#'):
                 # Catch if cyclictest stopped due to a breaktrace
                 if line.startswith('# Break value: '):
@@ -329,11 +336,11 @@ class Cyclictest(rtevalModulePrototype):
                 continue
 
             # Skipping blank lines
-            if len(line) == 0:
+            if not line:
                 continue
 
             vals = line.split()
-            if len(vals) == 0:
+            if not vals:
                 # If we don't have any values, don't try parsing
                 continue
 
@@ -343,12 +350,12 @@ class Cyclictest(rtevalModulePrototype):
                 self._log(Log.DEBUG, "cyclictest: unexpected output: %s" % line)
                 continue
 
-            for i,core in enumerate(self.__cpus):
+            for i, core in enumerate(self.__cpus):
                 self.__cyclicdata[core].bucket(index, int(vals[i+1]))
                 self.__cyclicdata['system'].bucket(index, int(vals[i+1]))
 
         # generate statistics for each RunData object
-        for n in self.__cyclicdata.keys():
+        for n in list(self.__cyclicdata.keys()):
             #print "reducing self.__cyclicdata[%s]" % n
             self.__cyclicdata[n].reduce()
             #print self.__cyclicdata[n]
@@ -424,7 +431,7 @@ if __name__ == '__main__':
     cfg = rtevalConfig({}, logger=l)
     prms = {}
     modprms = ModuleParameters()
-    for c, p in modprms.items():
+    for c, p in list(modprms.items()):
         prms[c] = p['default']
     cfg.AppendConfig('cyclictest', prms)
 
@@ -445,4 +452,4 @@ if __name__ == '__main__':
 
     xml = libxml2.newDoc('1.0')
     xml.setRootElement(rep_n)
-    xml.saveFormatFileEnc('-','UTF-8',1)
+    xml.saveFormatFileEnc('-', 'UTF-8', 1)
